@@ -18,5 +18,5 @@
 package org.jboss.classfilewriter.code;
 
 public enum StackEntryType {
-    TOP, INT, FLOAT, DOUBLE, LONG, NULL, UNINITIALIZED_THIS, OBJECT, UNITITIALIZED_OBJECT;
+    TOP, INT, FLOAT, DOUBLE, LONG, NULL, UNINITIALIZED_THIS, OBJECT, UNITITIALIZED_OBJECT
 }
