@@ -17,7 +17,7 @@
  */
 package org.jboss.classfilewriter.test.bytecode.f;
 
-import junit.framework.Assert;
+import org.junit.Assert;
 
 import org.jboss.classfilewriter.code.CodeAttribute;
 import org.jboss.classfilewriter.test.bytecode.MethodTester;
@@ -38,6 +38,6 @@ public class FastoreTest {
 
         ca.returnInstruction();
         mt.invoke();
-        Assert.assertEquals(1.0f, VALUE[1]);
+        Assert.assertEquals(1.0f, VALUE[1], 0);
     }
 }
