@@ -17,7 +17,7 @@
  */
 package org.jboss.classfilewriter.test.bytecode.i;
 
-import junit.framework.Assert;
+import org.junit.Assert;
 
 import org.jboss.classfilewriter.code.CodeAttribute;
 import org.jboss.classfilewriter.test.bytecode.MethodTester;
@@ -32,7 +32,7 @@ public class I2fTest {
         ca.ldc(3);
         ca.i2f();
         ca.returnInstruction();
-        Assert.assertEquals(3.0f, (float) mt.invoke());
+        Assert.assertEquals(3.0f, mt.invoke(), 0);
     }
 
 
