@@ -17,7 +17,7 @@
  */
 package org.jboss.classfilewriter.test.bytecode.i;
 
-import junit.framework.Assert;
+import org.junit.Assert;
 
 import org.jboss.classfilewriter.code.CodeAttribute;
 import org.jboss.classfilewriter.test.bytecode.MethodTester;
@@ -34,4 +34,4 @@ public class InegTest {
         ca.returnInstruction();
         Assert.assertEquals(-10, (int) mt.invoke(10));
     }
-}
\ No newline at end of file
+}
